@@ -641,7 +641,9 @@ class ImportFiles(flow.Action):
 
                 #region Call get_shot
                 shot_name = file_fullname.split('.')[0]
-                if shot_name.endswith('_'):
+                if shot_name.endswith('_') and shot_name[-3] == 't':
+                    shot_name = '_'.join(shot_name.split('_')[:-2])
+                elif shot_name.endswith('_'):
                     shot_name = shot_name[:-1]
                 shot = self.get_shot(shot_name)
                 if shot == False:
@@ -674,7 +676,7 @@ class ImportFiles(flow.Action):
                 if shot != 'Create':
                     if shot.tasks[preset.task_name.get()].files.has_mapped_name(target_name) == True:
                         rev = shot.tasks[preset.task_name.get()].files[target_name].get_head_revision()
-                        if rev and file_name.endswith('_') == False:
+                        if rev and file_name.endswith('_') == False or (file_name.endswith('_') == False and file_name[-3] != 't'):
                             if preset.optional_new_rev.get() == False:
                                 incorrect['files'].append({
                                     'name': '/'.join(path.split('/')[-2:]),
@@ -695,7 +697,7 @@ class ImportFiles(flow.Action):
 
                 #endregion
                     
-                # Add in valid list
+                #region Add in valid list
                 # Add in correct shot object
                 find_shot = False
                 for s in valid:
@@ -717,6 +719,7 @@ class ImportFiles(flow.Action):
                             'name': file_fullname
                         }]
                     })
+                #endregion
             if os.path.isdir(path):
                 #region Check dir name
                 dir_name = path.split('/')[-1]
@@ -856,7 +859,9 @@ class ImportFiles(flow.Action):
                     #region Checks for plas file
                     if '.plas' in file_fullname:
                         #region if plas name == dir name
-                        if file_name.endswith('_'):
+                        if file_name.endswith('_') and file_name[-3] == 't':
+                            file_name = '_'.join(file_name.split('_')[:-2])
+                        elif file_name.endswith('_'):
                             file_name = file_name[:-1]
                         if file_name != dir_name:
                             find_entry = False
@@ -891,7 +896,7 @@ class ImportFiles(flow.Action):
                         if shot != 'Create':
                             if shot.tasks[preset.task_name.get()].files.has_mapped_name(target_name) == True:
                                 rev = shot.tasks[preset.task_name.get()].files[target_name].get_head_revision()
-                                if rev and file_name.endswith('_') == False:
+                                if rev and file_name.endswith('_') == False or (file_name.endswith('_') == False and file_name[-3] != 't'):
                                     if preset.optional_new_rev.get() == False:
                                         find_entry = False
                                         for s in incorrect['shots']:
@@ -916,7 +921,7 @@ class ImportFiles(flow.Action):
 
                         #region init status
                             else:
-                                if file_name.endswith('_') == True:
+                                if file_name.endswith('_') or (file_name.endswith('_') and file_name[-3] == 't'):
                                     if preset.optional_init.get() == False:
                                         find_entry = False
                                         for s in incorrect['shots']:
@@ -1039,7 +1044,7 @@ class ImportFiles(flow.Action):
                 # Folder has a base and retake file
                 if shot.files_map.has_mapped_name(i['shot'] + '_plas') == True:
                     name, ext = f['name'].rsplit('.', 1)
-                    if name.endswith('_'):
+                    if name.endswith('_') or (name.endswith('_') and name[-3] == 't'):
                         continue
 
                 f_item = shot.files_map.add(name)
